@@ -3,7 +3,7 @@ use Moose;
 
 use 5.008005;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 my $MAX_SIZE = 500;
 my $TRIM_SIZE = 400;
@@ -235,7 +235,9 @@ sub generate_html {
 
 	foreach my $f (@feeds) {
 		$f->{latest_entry} = $latest_entry_of{ $f->{id} };
-        $f->{last_fetch_time} = localtime $f->{last_fetch_time};
+        #$f->{last_fetch_time} = localtime $f->{last_fetch_time};
+		##commented out on 2013.4.26 on the live site as it was generating uninitialized warnings
+		##and in the 0.31 hotfix
 	}
 
 
